==> clinical-variant-ark-4.1.3.tar.gz: clinical-variant-ark-4.1.3/setup.py <==
import os
from distutils.core import setup
from setuptools import find_packages
import pyark


test_deps = ['mock']

# read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='clinical-variant-ark',
    version=pyark.VERSION,
    description='A Python client for the Clinical Variant Ark',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    scripts=[],
    url='https://github.com/genomicsengland/pyark',
    download_url="https://github.com/genomicsengland/pyark/archive/v{}.tar.gz".format(pyark.VERSION),
    license='Apache',
    author=['Pablo Riesgo Ferreiro', 'Kevin Savage', 'William Bellamy'],
    author_email='pablo.riesgo-ferreiro@genomicsengland.co.uk',
    install_requires=[
        'requests',
        'furl==1.0.1',
        'gelreportmodels==7.2.10',
        'enum34',
        'pandas',
        'mock',
        'future',
        'pytest'
    ],
    tests_require=test_deps,
    extras_require={'test': test_deps},
    keywords=['CVA', 'pyark', 'clinical variant ark', 'Genomics England'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
      ]
)

==> clinical-variant-ark-4.1.10.tar.gz: clinical-variant-ark-4.1.10/setup.py <==
import os
from distutils.core import setup
from setuptools import find_packages
import pyark


test_deps = ['mock==3.0.5', 'pytest==4.6.4']

# read the contents of your README file
this_directory = os.path.abspath(os.path.dirname(__file__))

setup(
    name='clinical-variant-ark',
    version=pyark.VERSION,
    description='A Python client for the Clinical Variant Ark',
    packages=find_packages(),
    scripts=[],
    url='https://github.com/genomicsengland/pyark',
    download_url="https://github.com/genomicsengland/pyark/archive/v{}.tar.gz".format(pyark.VERSION),
    license='Apache',
    author=['Pablo Riesgo Ferreiro', 'Kevin Savage', 'William Bellamy'],
    author_email='pablo.riesgo-ferreiro@genomicsengland.co.uk',
    install_requires=[
        'requests==2.22.0',
        'furl==1.0.1',
        'gelreportmodels==7.4.1',
        'enum34==1.1.6',
        'future==0.17.1'
    ],
    tests_require=test_deps,
    extras_require={'test': test_deps, 'pandas': ['pandas==1.0.5']},
    keywords=['CVA', 'pyark', 'clinical variant ark', 'Genomics England'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
      ]
)
